
=============
API reference
=============

This page gives an overview of all public polars objects, functions and
methods. All classes and functions exposed in ``polars.*`` namespace are public.

.. toctree::
   :maxdepth: 2

   io
   functions
   series
   dataframe
   expression
   lazyframe
   testing
   config
